# inpystem python library

## Description

inpystem is an open source Python library which provides tools to reconstruct partially sampled 2D images as multi-band images.

inpystem's core is a set of reconstruction techniques such as interpolation, regularized least-square and dictionary learning methods. It provides a user interface which simplify the use of these techniques.

inpystem is mainly at the destination of the microscopy community so that it highly depends on the good library [HyperSpy](https://hyperspy.org/).

This library was originally developed by its creator Etienne Monier to handle EELS data and develop reconstruction algorithms. This was proposed afterwards to the microscopy community as a tool.

## Documentation

This project documentation is hosted by [ReadTheDocs](https://readthedocs.org/). To access to it, please follow [this link](https://inpystem.readthedocs.io/en/latest/index.html). 

## Licence

This library is distributed under the MIT license.
